@@ -68,4 +68,10 @@ assign_random_state <- function(state, envir = globalenv(), check_existence = TR
     }
 }
 
+# Get message from testthat::capture_error
+# copied from testthat:::cnd_message
+cnd_message <- function(x){
+  withr::local_options(c(rlang_backtrace_on_error = "none"))
+  conditionMessage(x)
+}
 
